pub struct DecreaseLiquidity {
pub liquidity: u128,
pub amount0_min: u64,
pub amount1_min: u64,
}Fields
liquidity: u128amount0_min: u64amount1_min: u64Trait Implementations
Sourceimpl ArrangeAccounts for DecreaseLiquidity
impl ArrangeAccounts for DecreaseLiquidity
type ArrangedAccounts = DecreaseLiquidityInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for DecreaseLiquidity
impl BorshDeserialize for DecreaseLiquidity
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DecreaseLiquidity
impl CarbonDeserialize for DecreaseLiquidity
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DecreaseLiquidity
impl Clone for DecreaseLiquidity
Sourcefn clone(&self) -> DecreaseLiquidity
fn clone(&self) -> DecreaseLiquidity
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecreaseLiquidity
impl Debug for DecreaseLiquidity
Sourceimpl<'de> Deserialize<'de> for DecreaseLiquidity
impl<'de> Deserialize<'de> for DecreaseLiquidity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DecreaseLiquidity
impl Hash for DecreaseLiquidity
Sourceimpl PartialEq for DecreaseLiquidity
impl PartialEq for DecreaseLiquidity
Sourceimpl Serialize for DecreaseLiquidity
impl Serialize for DecreaseLiquidity
impl Eq for DecreaseLiquidity
impl StructuralPartialEq for DecreaseLiquidity