pub struct DecreaseLiquidityEvent {
pub position_nft_mint: Pubkey,
pub liquidity: u128,
pub decrease_amount0: u64,
pub decrease_amount1: u64,
pub fee_amount0: u64,
pub fee_amount1: u64,
pub reward_amounts: [u64; 3],
pub transfer_fee0: u64,
pub transfer_fee1: u64,
}Fields
position_nft_mint: Pubkeyliquidity: u128decrease_amount0: u64decrease_amount1: u64fee_amount0: u64fee_amount1: u64reward_amounts: [u64; 3]transfer_fee0: u64transfer_fee1: u64Trait Implementations
Sourceimpl BorshDeserialize for DecreaseLiquidityEventwhere
Pubkey: BorshDeserialize,
u128: BorshDeserialize,
u64: BorshDeserialize,
[u64; 3]: BorshDeserialize,
impl BorshDeserialize for DecreaseLiquidityEventwhere
Pubkey: BorshDeserialize,
u128: BorshDeserialize,
u64: BorshDeserialize,
[u64; 3]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DecreaseLiquidityEvent
impl CarbonDeserialize for DecreaseLiquidityEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DecreaseLiquidityEvent
impl Clone for DecreaseLiquidityEvent
Sourcefn clone(&self) -> DecreaseLiquidityEvent
fn clone(&self) -> DecreaseLiquidityEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecreaseLiquidityEvent
impl Debug for DecreaseLiquidityEvent
Sourceimpl<'de> Deserialize<'de> for DecreaseLiquidityEvent
impl<'de> Deserialize<'de> for DecreaseLiquidityEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DecreaseLiquidityEvent
impl Hash for DecreaseLiquidityEvent
Sourceimpl PartialEq for DecreaseLiquidityEvent
impl PartialEq for DecreaseLiquidityEvent
Sourceimpl Serialize for DecreaseLiquidityEvent
impl Serialize for DecreaseLiquidityEvent
impl Eq for DecreaseLiquidityEvent
impl StructuralPartialEq for DecreaseLiquidityEvent