pub struct DecreaseLiquidityV2 {
pub liquidity: u128,
pub amount0_min: u64,
pub amount1_min: u64,
}Fields
liquidity: u128amount0_min: u64amount1_min: u64Trait Implementations
Sourceimpl ArrangeAccounts for DecreaseLiquidityV2
impl ArrangeAccounts for DecreaseLiquidityV2
type ArrangedAccounts = DecreaseLiquidityV2InstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for DecreaseLiquidityV2
impl BorshDeserialize for DecreaseLiquidityV2
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DecreaseLiquidityV2
impl CarbonDeserialize for DecreaseLiquidityV2
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DecreaseLiquidityV2
impl Clone for DecreaseLiquidityV2
Sourcefn clone(&self) -> DecreaseLiquidityV2
fn clone(&self) -> DecreaseLiquidityV2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecreaseLiquidityV2
impl Debug for DecreaseLiquidityV2
Sourceimpl<'de> Deserialize<'de> for DecreaseLiquidityV2
impl<'de> Deserialize<'de> for DecreaseLiquidityV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DecreaseLiquidityV2
impl Hash for DecreaseLiquidityV2
Sourceimpl PartialEq for DecreaseLiquidityV2
impl PartialEq for DecreaseLiquidityV2
Sourceimpl Serialize for DecreaseLiquidityV2
impl Serialize for DecreaseLiquidityV2
impl Eq for DecreaseLiquidityV2
impl StructuralPartialEq for DecreaseLiquidityV2